@@ -24,4 +24,6 @@
 #
 ###############################################################################
 
-__version__ = u'19.11.2'
+__version__ = '22.2.1'
+
+__build__ = u'00000000-0000000'
